Class: Google::Apis::ApimV1alpha::Entitlement
- Inherits:
-
Object
- Object
- Google::Apis::ApimV1alpha::Entitlement
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apim_v1alpha/classes.rb,
lib/google/apis/apim_v1alpha/representations.rb,
lib/google/apis/apim_v1alpha/representations.rb
Overview
Entitlement stores data related to API Observation entitlement for a given project
Instance Attribute Summary collapse
-
#api_observation_entitled ⇒ Boolean
(also: #api_observation_entitled?)
Whether API Observation is entitled.
-
#billing_project_number ⇒ Fixnum
Project number of associated billing project that has Apigee and Advanced API Security entitled.
-
#create_time ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Entitlement
constructor
A new instance of Entitlement.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Entitlement
Returns a new instance of Entitlement.
297 298 299 |
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 297 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_observation_entitled ⇒ Boolean Also known as: api_observation_entitled?
Whether API Observation is entitled.
Corresponds to the JSON property apiObservationEntitled
272 273 274 |
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 272 def api_observation_entitled @api_observation_entitled end |
#billing_project_number ⇒ Fixnum
Project number of associated billing project that has Apigee and Advanced API
Security entitled.
Corresponds to the JSON property billingProjectNumber
279 280 281 |
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 279 def billing_project_number @billing_project_number end |
#create_time ⇒ String
Output only. The time of the entitlement creation.
Corresponds to the JSON property createTime
284 285 286 |
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 284 def create_time @create_time end |
#name ⇒ String
Identifier. The entitlement resource name projects/project/locations/
location/entitlement
Corresponds to the JSON property name
290 291 292 |
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 290 def name @name end |
#update_time ⇒ String
Output only. The time of the entitlement update.
Corresponds to the JSON property updateTime
295 296 297 |
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 295 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
302 303 304 305 306 307 308 |
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 302 def update!(**args) @api_observation_entitled = args[:api_observation_entitled] if args.key?(:api_observation_entitled) @billing_project_number = args[:billing_project_number] if args.key?(:billing_project_number) @create_time = args[:create_time] if args.key?(:create_time) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |