Class: Google::Apis::ApimV1alpha::HttpOperationHttpResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apim_v1alpha/classes.rb,
lib/google/apis/apim_v1alpha/representations.rb,
lib/google/apis/apim_v1alpha/representations.rb

Overview

An aggregation of HTTP responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpOperationHttpResponse

Returns a new instance of HttpOperationHttpResponse.



473
474
475
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headersHash<String,Google::Apis::ApimV1alpha::HttpOperationHeader>

Unordered map from header name to header metadata Corresponds to the JSON property headers



466
467
468
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 466

def headers
  @headers
end

#response_codesHash<String,Fixnum>

Map of status code to observed count Corresponds to the JSON property responseCodes

Returns:

  • (Hash<String,Fixnum>)


471
472
473
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 471

def response_codes
  @response_codes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



478
479
480
481
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 478

def update!(**args)
  @headers = args[:headers] if args.key?(:headers)
  @response_codes = args[:response_codes] if args.key?(:response_codes)
end