Class: Google::Apis::ApimV1alpha::HttpOperationQueryParam
- Inherits:
-
Object
- Object
- Google::Apis::ApimV1alpha::HttpOperationQueryParam
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apim_v1alpha/classes.rb,
lib/google/apis/apim_v1alpha/representations.rb,
lib/google/apis/apim_v1alpha/representations.rb
Overview
An aggregation of HTTP query parameter occurrences.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
The number of occurrences of this query parameter across transactions.
-
#data_type ⇒ String
Data type of path param Corresponds to the JSON property
dataType. -
#name ⇒ String
Name of query param Corresponds to the JSON property
name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpOperationQueryParam
constructor
A new instance of HttpOperationQueryParam.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpOperationQueryParam
Returns a new instance of HttpOperationQueryParam.
528 529 530 |
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 528 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
The number of occurrences of this query parameter across transactions.
Corresponds to the JSON property count
516 517 518 |
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 516 def count @count end |
#data_type ⇒ String
Data type of path param
Corresponds to the JSON property dataType
521 522 523 |
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 521 def data_type @data_type end |
#name ⇒ String
Name of query param
Corresponds to the JSON property name
526 527 528 |
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 526 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
533 534 535 536 537 |
# File 'lib/google/apis/apim_v1alpha/classes.rb', line 533 def update!(**args) @count = args[:count] if args.key?(:count) @data_type = args[:data_type] if args.key?(:data_type) @name = args[:name] if args.key?(:name) end |